@@ -236,7 +236,7 @@ unsigned char *extract_zip(f_state *s, u_int64_t c_offset, unsigned char *founda
 #ifdef DEBUG
 		printf("Found a %s\n", needle->suffix);
 #endif
-		return foundat;
+		return foundat-2;
 	}
 
 	if (bytes_to_search > buflen - (currentpos - buf))
@@ -1779,7 +1779,7 @@ unsigned char *extract_jpeg(f_state *s, u_int64_t c_offset, unsigned char *found
 			}
 	}
 
-	/*All jpegs must contact a Huffman marker as well as a quantization table*/
+	/*All jpegs must contain a Huffman marker as well as a quantization table*/
 	if (!hasTable || !hasHuffman)
 	{
 #ifdef DEBUG
